@@ -60,10 +60,10 @@ void SettingsWindow::selectUnsolvedColor()
 
 void SettingsWindow::bgToolButtonClicked()
 {
-    QString fileName = QFileDialog::getOpenFileName(this, i18n("Select Background"), QString(),
+    QString fileName = QFileDialog::getOpenFileName(this, i18nc("@title:window", "Select Background"), QString(),
                                                     i18n("Image Files (*.png *.jpg)"));
 
-    if (fileName.isNull()) {
+    if (fileName.isEmpty()) {
         return;
     }
 
